@@ -2,10 +2,12 @@ package Test2::Plugin::SourceDiag;
 use strict;
 use warnings;
 
-our $VERSION = '0.000002';
+our $VERSION = '0.000003';
 
 use Test2::Event::Diag;
 
+use Scalar::Util();
+
 use Test2::API qw{
     test2_add_callback_post_load
     test2_stack
@@ -39,7 +41,8 @@ sub context_init {
     my $level  = $args{level} || 1;
 
     @caller = caller(1 + $level);
-    $ctx->trace->{args} = [@DB::args];
+
+    $ctx->trace->{args} = [grep { !Scalar::Util::blessed($_) || !$_->isa('Test::Builder')} @DB::args];
 }
 
 sub filter {
